using System;
using System.Collections.Generic;
using System.Text;
using System.Drawing;
using System.Windows.Forms;

namespace DisplayAnywhere
{
    enum DisplayMode
    {
        Portrait,
        Landscape,
		General
    }

    class DisplayManager
    {
        public static DisplayMode GetDisplayMode()
        {
            Rectangle screenBounds = Screen.PrimaryScreen.Bounds;
            DisplayMode mode;

			float ratio = ((float)screenBounds.Width / (float)screenBounds.Height);

            if (ratio < 0.76F)
            {
                mode = DisplayMode.Portrait;
            }
            else if (ratio > 1.3F)
            {
                mode = DisplayMode.Landscape;
            }
			else
			{
				mode = DisplayMode.General;
			}

            return mode;

        }

        const float designWidthPortrait = 240;
        const float designHeightPortrait = 320;

        public static void GetDisplayRatiosByScreenSize(ref float widthRatio, ref float heightRatio)
        {
            Rectangle screenBounds = Screen.PrimaryScreen.Bounds;

            if (GetDisplayMode() == DisplayMode.Portrait)
            {
                widthRatio = screenBounds.Width / designWidthPortrait;
                heightRatio = screenBounds.Height / designHeightPortrait;
            }
            else
            {
                widthRatio = screenBounds.Width / designHeightPortrait;
                heightRatio = screenBounds.Height / designWidthPortrait;
            }
        }


        #region Ժ

        const float designDpiX = 96.0F;
        const float designDpiY = 96.0F;

        public static void GetDisplayRatiosByDpi(Form form, ref float widthRatio, ref float heightRatio)
        {
            float dpiX = 0.0F;
            float dpiY = 0.0F;

            using (Graphics graphics = form.CreateGraphics())
            {
                dpiX = graphics.DpiX;
                dpiY = graphics.DpiY;
            }
            widthRatio = dpiX / designDpiX;
            heightRatio = dpiY / designDpiY;
        }
        #endregion
    }
}
